@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-import json
+from json import dumps as json_dumps
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Union
 from CloudflareAPI.core import CFBase, Request
@@ -14,14 +14,16 @@ class Worker(CFBase):
             self.data = dict(body_part="script", bindings=[])
 
         def __call__(self):
-            return (None, json.dumps(self.data), "application/json")
+            return (None, json_dumps(self.data), "application/json")
 
         def _sanitize(self, text: str):
-            return text.strip().replace(" ","_").upper()
+            return text.strip().replace(" ", "_").upper()
 
         def add_binding(self, name: str, namespace_id: str):
             binding = dict(
-                name=self._sanitize(name), type="kv_namespace", namespace_id=namespace_id
+                name=self._sanitize(name),
+                type="kv_namespace",
+                namespace_id=namespace_id,
             )
             self.data["bindings"].append(binding)
 
@@ -32,20 +34,24 @@ class Worker(CFBase):
         def add_secret(self, name: str, secret: str):
             binding = dict(name=self._sanitize(name), type="secret_text", text=secret)
             self.data["bindings"].append(binding)
-        
 
-    def __init__(self, request: Request, account_id: str) -> None:
-        self.req = request
-        self.base_path = f"/accounts/{account_id}/workers/scripts"
-        self.cron = Cron(request, account_id)
-        self.subdomain = Subdomain(request, account_id)
-        super().__init__()
+        def __repr__(self) -> str:
+            return json_dumps(self.data, indent=2)
+
+    def __init__(self, account_id: str) -> None:
+        self.account_id = account_id
+        base_path = f"/accounts/{self.account_id}/workers/scripts"
+        self.request = self.get_request(base_path)
+        self.cron = Cron(self.account_id)
+        self.subdomain = Subdomain(self.account_id)
 
     def list(
-        self, detailed: bool = False, params: Optional[Dict[str, Any]] = None
+        self,
+        detailed: bool = False,
+        params: Optional[Dict[str, Any]] = None,
+        formated: bool = False,
     ) -> List:
-        url = self.build_url()
-        workers = self.req.get(url, params=params)
+        workers = self.request.get(params=params)
         if detailed:
             wlist = [
                 {
@@ -59,29 +65,27 @@ class Worker(CFBase):
             ]
         else:
             wlist = [worker["id"] for worker in workers]
+        if formated:
+            return json_dumps(wlist, indent=2)
         return wlist
 
     def download(self, name: str, directory: str = "./workers") -> int:
-        url = self.build_url(name)
-        data = self.req.get(url)
+
+        data = self.request.get(name)
         directory = Path(directory)
         directory.mkdir(parents=True, exist_ok=True)
         directory.resolve(strict=True)
         file = directory / f"{name}.js"
         return file.write_text(data)
 
-    def upload(
-        self,
-        name: str,
-        file: str,
-        metadata: Optional[Metadata] = None
-    ) -> Any:
+    def upload(self, name: str, file: str, metadata: Optional[Metadata] = None) -> Any:
         file = Path(file)
         file.resolve(strict=True)
-        url = self.build_url(name)
         if metadata is None:
             data = file.read_text()
-            return self.req.put(url, data=data, headers={"Content-Type": "application/javascript"})
+            return self.request.put(
+                name, data=data, headers={"Content-Type": "application/javascript"}
+            )
         miltipart_data = {
             "metadata": metadata(),
             "script": (
@@ -90,16 +94,13 @@ class Worker(CFBase):
                 "application/javascript",
             ),
         }
-        return self.req.put(url, files=miltipart_data)
+        return self.request.put(name, files=miltipart_data)
 
     def deploy(self, name: str) -> bool:
-        url = self.build_url(f"{name}/subdomain")
-        return self.req.post(url, json={"enabled": True})
+        return self.request.post(f"{name}/subdomain", json={"enabled": True})
 
     def undeploy(self, name: str) -> bool:
-        url = self.build_url(f"{name}/subdomain")
-        return self.req.post(url, json={"enabled": False})
+        return self.request.post(f"{name}/subdomain", json={"enabled": False})
 
     def delete(self, name: str) -> bool:
-        url = self.build_url(name)
-        return self.req.delete(url)
+        return self.request.delete(name)
