@@ -6,18 +6,16 @@ from CloudflareAPI.exceptions import CFError
 
 
 class Subdomain(CFBase):
-    def __init__(self, request: Request, account_id: str) -> None:
-        self.req = request
-        self.base_path = f"/accounts/{account_id}/workers/subdomain"
-        super().__init__()
+    def __init__(self, account_id: str) -> None:
+        self.account_id = account_id
+        base_path = f"/accounts/{self.account_id}/workers/subdomain"
+        self.request = self.get_request(base_path)
 
     def create(self, name: str) -> str:
         name = name.replace("_", "-").lower()
         if not match("^[a-z0-9]([a-z0-9-]{0,61}[a-z0-9])?$", name):
             raise CFError("Subdomain is not valid")
-        url = self.build_url()
-        return self.req.put(url, json=dict(subdomain=name))
+        return self.request.put(json=dict(subdomain=name))
 
     def get(self) -> str:
-        url = self.build_url()
-        return self.req.get(url)["subdomain"]
+        return self.request.get()["subdomain"]
